/* board.c		8/3/91
 *
 * Copyright 1991-1996  Perry R. Ross
 *
 *  This program is free software; you can redistribute it and/or modify 
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License  
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "ldb.h"

/*----------------------------------------------------------------------
 *	newboard -- set up a board array for a new game
 *
 * This function initializes a board array so that it is set up
 * properly for a new game.  It is passed two characters that are
 * used to draw the pieces for the board.  C1 is the color for the
 * upbound player, and c2 is the color for the downbound player.
 *----------------------------------------------------------------------
 */

void
newboard(b,c1,c2)
board b;
char c1, c2;
{
int i;

for (i = 0; i < BOARDSIZE; i++) {
	b[i].qty = 0;			/* init to empty */
	b[i].color = '-';		/* init to invalid color */
	}
b[1].qty = 2;				/* 2 c1's on 1 point */
b[1].color = c1;
b[6].qty = 5;				/* 5 c2's on 6 point */
b[6].color = c2;
b[8].qty = 3;				/* 3 c2's on 8 point */
b[8].color = c2;
b[12].qty = 5;				/* 5 c1's on 12 point */
b[12].color = c1;
b[13].qty = 5;				/* 5 c2's on 13 point */
b[13].color = c2;
b[17].qty = 3;				/* 3 c1's on 17 point */
b[17].color = c1;
b[19].qty = 5;				/* 5 c1's on 19 point */
b[19].color = c1;
b[24].qty = 2;				/* 2 c2's on 24 point */
b[24].color = c2;
}


/*----------------------------------------------------------------------
 *	copyboard -- make a copy a board array
 *
 * This is a convenience function that copies an entire board. The
 * source is given as "f", and the destination as "t".
 *----------------------------------------------------------------------
 */

void
copyboard(f,t)
board f, t;
{
int i;

for (i = 0; i < BOARDSIZE; i++)
	t[i] = f[i];
}


/*----------------------------------------------------------------------
 *	clear_mycmt -- erase my current comment for a game
 *----------------------------------------------------------------------
 */

void
clear_mycmt(g)
struct game *g;
{

if (g->mycmt != NULL) {
	free(g->mycmt);
	g->mycmt = NULL;
	}
if (g->mycmt2 != NULL) {
	free(g->mycmt2);
	g->mycmt2 = NULL;
	}
}


/*----------------------------------------------------------------------
 *	clear_opcmt -- erase opponent's current comment for a game
 *----------------------------------------------------------------------
 */

void
clear_opcmt(g)
struct game *g;
{

if (g->opcmt != NULL) {
	free(g->opcmt);
	g->opcmt = NULL;
	}
if (g->opcmt2 != NULL) {
	free(g->opcmt2);
	g->opcmt2 = NULL;
	}
}
